@@ -166,7 +166,7 @@ sub _make_field {
         $do_update = 1;
     }
     my $field_ns = $self->field_name_space;
-    my @field_name_space = ref $field_ns eq 'ARRAY' ? @$field_ns : $field_ns;
+    my @field_name_space = ref $field_ns eq 'ARRAY' ? @$field_ns : $field_ns if length $field_ns;
     my @classes;
     # '+'-prefixed fields could be full namespaces
     if ( $type =~ s/^\+// )
@@ -301,7 +301,7 @@ HTML::FormHandler::BuildFields - role to build field array
 
 =head1 VERSION
 
-version 0.35002
+version 0.35003
 
 =head1 SYNOPSIS
 
